#
# spec file for package tcpdump
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tcpdump
Version:        4.5.1
Release:        6.3
Url:            http://www.tcpdump.org/
Summary:        A Packet Sniffer
License:        BSD-3-Clause
Group:          Productivity/Networking/Diagnostic
Source:         http://www.tcpdump.org/release/%{name}-%{version}.tar.gz
Source1:        tcpdump-qeth
Source2:        http://www.tcpdump.org/release/%{name}-%{version}.tar.gz.sig
Source3:        http://www.tcpdump.org/tcpdump-workers.asc#/%{name}.keyring
Patch0:         tcpdump-4.0.0-prototypes.patch
Patch2:         tcpdump-4.0.0-aliasing.patch
Patch3:         tcpdump-CVE-2014-8767.patch
Patch4:         tcpdump-CVE-2014-8768.patch
Patch5:         tcpdump-CVE-2014-8769.patch
Patch6:         0001-Clean-up-error-message-printing.patch
Patch7:         tcpdump-CVE-2014-9140.patch
Patch9:         0002-test-case-files-for-CVE-2015-2153-2154-2155.patch
Patch10:        0003-test-case-for-cve2015-0261-corrupted-IPv6-mobility-h.patch

BuildRequires:  libpcap-devel
BuildRequires:  libsmi-devel
BuildRequires:  openssl-devel
%if 0%{?suse_version} >= 1230
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This program can "read" all or only certain packets going over the
ethernet. It can be used to debug specific network problems.


%prep
%setup -q
%patch0
%patch2
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch9 -p1
%patch10 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS -Wall -DGUESS_TSO -fstack-protector -fno-strict-aliasing"
%configure \
  --enable-ipv6
make

%install
make DESTDIR=$RPM_BUILD_ROOT install
%ifarch s390 s390x
  install -D -m 755 $RPM_SOURCE_DIR/tcpdump-qeth $RPM_BUILD_ROOT%{_sbindir}
%endif
rm %{buildroot}/%{_sbindir}/tcpdump.%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc CHANGES CREDITS LICENSE README* *.awk
%doc %{_mandir}/man?/*
%{_sbindir}/*

%changelog
* Fri May 13 2016 vcizek@suse.com
- Don't install the versioned binary (bsc#944294)
* Thu Mar 19 2015 vcizek@suse.com
- security update:
  * CVE-2015-0261: issues with IPv6 mobility printer (bnc#922220)
  * CVE-2014-9140: issue with PPP printer (bnc#923142)
  * CVE-2015-2155: issue with force printer (bnc#922223)
  * CVE-2015-2154: issue with ethernet printer (bnc#922222)
  * CVE-2015-2153: issue with tcp printer (bnc#922221)
- added patches:
  * tcpdump-CVE-2014-9140.patch
  * 0002-test-case-files-for-CVE-2015-2153-2154-2155.patch
  * 0003-test-case-for-cve2015-0261-corrupted-IPv6-mobility-h.patch
* Thu Dec 11 2014 vcizek@suse.com
- fix CVE-2014-8767 (bnc#905870)
  * denial of service in verbose mode using malformed OLSR payload
  * added tcpdump-CVE-2014-8767.patch
- fix CVE-2014-8768 (bnc#905871)
  * denial of service in verbose mode using malformed Geonet payload
  * added tcpdump-CVE-2014-8768.patch
- fix CVE-2014-8769 (bnc#905872)
  * unreliable output using malformed AOVD payload
  * added tcpdump-CVE-2014-8769.patch
  * added 0001-Clean-up-error-message-printing.patch
* Sat Dec 14 2013 andreas.stieger@gmx.de
- update to 4.5.1
  Version 4.5.0 revised for non-code related edits
  - some NFSv4 fixes for printing
  - fix printing of unknown TCP options, and tcp fast-open
  - fixes for syslog parser
  - some gcc-version-specific flag tuning
  - improvements to babel printing
  - add OpenFlow 1.0 (no SSL) and test cases
  - GeoNet printer.
  - added STBC Rx support
  - improvements to DHCPv6 decoder
  - clarify which autoconf is needed
  - Point users to the the-tcpdump-group repository on GitHub rather
    than the mcr repository
  - Add MSDP printer.
  - Fixed IPv6 check on Solaris and other OSes requiring extra
    networking libraries.
  - Add support for VXLAN (draft-mahalingam-dutt-dcops-vxlan-03),
    and add "vxlan" as an option for -T.
  - Add support for OTV (draft-hasmit-otv-04).
    fixes for DLT_IEEE802_11_RADIO datalink types
  - added MPTCP decoder
* Fri Sep 13 2013 andreas.stieger@gmx.de
- verify source signature
* Wed Sep 11 2013 reddwarf@opensuse.org
- update to 4.4.0
  - RPKI-RTR (RFC6810) is now official (TCP Port 323)
  - Fix detection of OpenSSL libcrypto.
  - Add DNSSL (RFC6106) support.
  - Add "radius" as an option for -T.
  - Update Action codes for handle_action function according to
    802.11s amendment.
  - Decode DHCPv6 AFTR-Name option (RFC6334).
  - Updates for Babel.
  - Fix printing of infinite lifetime in ICMPv6.
  - Added support for SPB, SPBM Service Identifier, and Unicast
    Address sub-TLV in ISIS.
  - Decode RIPv2 authentication up to RFC4822.
  - Fix RIP Request/full table decoding issues.
  - On Linux systems with cap-ng.h, drop root privileges
    using Linux Capabilities.
  - Add support for reading multiple files.
* Fri Jun 15 2012 jslaby@suse.de
- remove tcpdump-4.0.0-uninitialized.patch, it's solved differently
* Thu Jun 14 2012 jslaby@suse.de
- update to 4.3.0
  - fixes for forces: SPARSE data (per RFC 5810)
  - some more test cases added
  - updates to documentation on -l, -U and -w flags.
  - Fix printing of BGP optional headers.
  - Tried to include DLT_PFSYNC support, failed due to headers required.
  - added TIPC support.
  - Fix LLDP Network Policy bit definitions.
  - fixes for IGMPv3's Max Response Time: it is in units of 0.1 second.
  - SIGUSR1 can be used rather than SIGINFO for stats
  - permit -n flag to affect print-ip for protocol numbers
  - ND_OPT_ADVINTERVAL is in milliseconds, not seconds
  - Teach PPPoE parser about RFC 4638
* Tue Jan  3 2012 puzel@suse.com
- update to 4.2.1
  - Only build the Babel printer if IPv6 is enabled.
  - Support Babel on port 6696 as well as 6697.
  - Include ppi.h in release tarball.
  - Include all the test files in the release tarball, and don't
    "include" test files that no longer exist.
  - Don't assume we have <rpc/rpc.h> - check for it.
  - Support "-T carp" as a way of dissecting IP protocol 112 as CARP
    rather than VRRP.
  - Support Hilscher NetAnalyzer link-layer header format.
  - Constify some pointers and fix compiler warnings.
  - Get rid of never-true test.
  - Fix an unintended fall-through in a case statement in the ARP
    printer.
  - Fix several cases where sizeof(sizeof(XXX)) was used when just
    sizeof(XXX) was intended.
  - Make stricter sanity checks in the ES-IS printer.
  - Get rid of some GCCisms that caused builds to fail with compilers
    that don't support them.
  - Fix typo in man page.
  - Added length checks to Babel printer.
- drop tcpdump-4.2.0-ppi.patch (upstream)
* Mon Nov 28 2011 vcizek@suse.com
- update to 4.2.0
  * patch that adds missing ppi.h
  * Summary for 4.2.0
  - merged 802.15.4 decoder from Dmitry Eremin-Solenikov <dbaryshkov
    at gmail dot com>
  - updates to forces for new port numbers
  - Use "-H", not "-h", for the 802.11s option. (-h always help)
  - Better ICMPv6 checksum handling.
  - add support for the RPKI/Router Protocol, per -ietf-sidr-rpki-rtr-12
  - get rid of uuencoded pcap test files, git can do binary.
  - sFlow changes for 64-bit counters.
  - fixes for PPI packet header handling and printing.
  - Add DCB Exchange protocol (DCBX) version 1.01.
  - Babel dissector, from Juliusz Chroboczek and GrÃ©goire Henry.
  - improvements to radiotap for rate values > 127.
  - Many improvements to ForCES decode, including fix SCTP TML port
  - updated RPL type code to RPL-17 draft
  - Improve printout of DHCPv6 options.
  - added support and test case for QinQ (802.1q VLAN) packets
  - Handle DLT_IEEE802_15_4_NOFCS like DLT_IEEE802_15_4.
  - Build fixes for Sparc and other machines with alignment restrictions.
  - Merged changes from Debian package.
  - PGM: Add ACK decoding and add PGMCC DATA and FEEDBACK options.
  - Build fixes for OSX (Snow Leopard and others)
  - Add support for IEEE 802.15.4 packets
  * Summary for 4.1.2 tcpdump release
  - If -U is specified, flush the file after creating it, so it's
    not zero-length
  - Fix TCP flags output description, and some typoes, in the man
    page
  - Add a -h flag, and only attempt to recognize 802.11s mesh
    headers if it's set
  - When printing the link-layer type list, send *all* output to
    stderr
  - Include the CFLAGS setting when configure was run in the
    compiler flags
* Tue Apr  6 2010 puzel@novell.com
- update to tcpdump-4.1.1
  * Don't blow up if a zero-length link-layer address is passed to
    linkaddr_string()
  * Fix printing of MAC addresses for VLAN frames with a length
    field
  * Add some additional bounds checks and use the EXTRACT_ macros
    more
  * Add a -b flag to print the AS number in BGP packets in ASDOT
    notation rather than ASPLAIN notation
  * Add ICMPv6 RFC 5006 support
  * Decode the access flags in NFS access requests
  * Handle the new DLT_ for memory-mapped USB captures on Linux
  * Make the default snapshot (-s) the maximum
  * Print name of device (when -L is used)
  * Print new TCP flags
  * Add support for RPL DIO
  * Add support for TCP User Timeout (UTO)
  * Add support for non-standard Ethertypes used by 3com PPPoE gear
  * Add support for 802.11n and 802.11s
  * Add support for Transparent Ethernet Bridge ethertype in GRE
  * Add 4 byte AS support for BGP printer
  * Add support for the MDT SAFI 66 BG printer
  * Add basic IPv6 support to print-olsr
  * Add USB printer
  * Add printer for ForCES
  * Handle frames with an FCS
  * Handle 802.11n Control Wrapper, Block Acq Req and Block Ack frames
  * Fix TCP sequence number printing
  * Report 802.2 packets as 802.2 instead of 802.3
- drop tcpdump-4.0.0-autoconf.patch (not needed with new autoconf)
- compile with -fno-strict-aliasing
* Wed Jan 14 2009 prusnak@suse.cz
- updated to 4.0.0
  * Add support for Bluetooth Sniffing
  * Add support for Realtek Remote Control Protocol (openrrcp.org.ru)
  * Add support for 802.11 AVS
  * Add support for SMB over TCP
  * Add support for 4 byte BGP AS printing
  * Add support for compiling on case-insensitive file systems
  * Add support for ikev2 printing
  * Update support for decoding AFS
  * Update DHCPv6 printer
  * Use newer libpcap API's (allows -B option on all platforms)
  * Add -I to turn on monitor mode
  * Bugfixes in lldp, lspping, dccp, ESP, NFS printers
  * Cleanup unused files and various cruft
- dropped obsoleted juniper.patch (included in update)
* Tue Jan  8 2008 prusnak@suse.cz
- updated to 3.9.8
  * Rework ARP printer
  * Rework OSPFv3 printer
  * Add support for Frame-Relay ARP
  * Decode DHCP Option 121 (RFC 3442 Classless Static Route)
  * Decode DHCP Option 249 (MS Classless Static Route) the same as Option 121
  * TLV: Add support for Juniper .pcap extensions
  * Print EGP header in new-world-order style
  * Converted print-isakmp.c to NETDISSECT
  * Moved AF specific stuff into af.h
  * Test subsystem now table driven, and saves outputs and diffs to one place
  * Require <net/pfvar.h> for pf definitions - allows reading of pflog formatted
    libpcap files on an OS other than where the file was generated
* Thu Jul 26 2007 prusnak@suse.cz
- updated to 3.9.7
  * NFS: Print unsigned values as such
  * RX: parse safely
  * BGP: fixes for IPv6-less builds
  * 801.1ag: use standard codepoint
  * use /dev/bpf on systems with such a device
  * 802.11: print QoS data, avoid dissect of no-data frame, ignore padding
  * smb: make sure that we haven't gone past the end of the captured data
  * smb: squelch an uninitialized complaint from coverity
  * NFS: from NetBSD; don't interpret the reply as a possible NFS reply if it got MSG_DENIED
  * BGP: don't print TLV values that didn't fit, from www.digit-labs.org
  * revised INSTALL.txt about libpcap dependancy
- dropped obsolete patch:
  * bgp-overflow.diff (fixed in update)
  * 802_11-overflow.diff (included in update)
- changed libpcap to libpcap-devel in BuildRequires
* Thu Jul 12 2007 prusnak@suse.cz
- update to 3.9.6
  * added support for:
  - OIF RSVP Extensions UNI 1.0 Rev. 2 and additional RSVP objects
  - Message-id NACK c-type
  - 802.3ah loopback ctrl msg
  - Multiple-STP as per 802.1s
  - rapid-SPT as per 802.1w
  - CFM Link-trace msg, Link-trace-Reply msg,
  - unidirectional link detection
  - the olsr protocol as per RFC 3626 plus the LQ extensions from olsr.org
  - variable-length checksum in DCCP, as per section 9 of RFC 4340
  - per-VLAN spanning tree and per-VLAN rapid spanning tree
  - Multiple-STP as per 802.1s
  - the cisco propriatry 'dynamic trunking protocol'
  - the cisco proprietary VTP protocol
  - additional values in pflog
  * changes to both TCP and IP Printer Output
  * fixed a potential buffer overflow in the 802.11 printer
  * print basic info about a few more Cisco LAN protocols
  * mDNS cleanup
  * ICMP MPLS rework of the extension code
  * use the correct codepoint for the OSPF simple text auth token entry
  * use safeputs to print the password
  * update dhcp6 options table as per IETF standardization activities
- fixed overflow in bgp (bgp-overflow.patch) [#291356]
* Fri Mar  2 2007 prusnak@suse.cz
- fixed one byte overflow (802_11-overflow.diff) [#250163]
* Wed Jan  3 2007 prusnak@suse.cz
- update to 3.9.5
  * Fixes for 64bit compiling
  * Updated list of DNS RR typecodes
  * Add basic support for keyed authentication TCP option
  * Fix printing for 4.4BSD/NetBSD NFS Filehandles
  * Add support for:
  - Frame-Relay ARP
  - parsing Juniper .pcap files
  - FRF.16 Multilink Frame-Relay (DLT_MFR)
  - PIMv2 checksum verification
  - further dissection of the IPCP Compression Option
  - Cisco's proposed VQP protocol
  - Cisco style NLPID encapsulation
  - PPP over Frame-Relay
  - Address-Withdraw and Label-Withdraw Msgs
  - BFD Discriminator TLV
  - BGP signaled VPLS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 mjancar@suse.cz
- compile with -fstack-protector
* Mon Jan  9 2006 mjancar@suse.cz
- update to 3.9.4
- drop obsolete patches
  * tcpdump-3.9.4-overflow.diff
* Thu Sep  1 2005 mjancar@suse.cz
- enable support for TSO packets (#114159)
* Fri Aug  5 2005 cthiel@suse.de
- fixed buffer overflow in addrtoname.c:499
* Tue Aug  2 2005 mjancar@suse.cz
- update to 3.9.3
* Thu Aug  5 2004 postadal@suse.cz
- updated to version 3.8.3
- removed obsoleted patches (isakmp-fix2, isakmp-fix3, radius-fix)
* Mon Mar 29 2004 postadal@suse.cz
- fixed overflow in ISAKMP (CAN-2004-0183) [#36828]
* Fri Feb  6 2004 ro@suse.de
- fix configure.in (test for pcap_debug was broken)
* Tue Jan 20 2004 postadal@suse.cz
- updated to version 3.8.1
  * fixed security bug in L2TP (CAN-2003-1029)
- removed obsoleted patches (isakmp-buffer-overflow-fix, compile)
- fixed security bugs in these parsers: RADIUS (CAN-2004-0055),
  ISAKMP (CAN-2004-0057) [#33763]
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Jan  6 2004 postadal@suse.cz
- fixed two remotely exploitable buffer overflows in the ISAKMP parser
  [#33763] (CAN-2003-0989)
* Thu Jul 24 2003 postadal@suse.cz
- updated to version 3.7.2
- removed obsoleted patches (tcpdump-nfs-fix, tcpdump-isakmp, tcpdump-bgp)
* Wed May  7 2003 ro@suse.de
- make it compile with current glibc headers
  (move include of netinet/in.h further up)
* Wed Mar  5 2003 postadal@suse.cz
- fixed security bugs in parsing ISAKMP, BGP and NFS
* Tue Oct  1 2002 froh@suse.de
- s390/s390x: dumping of qeth interfaces needs some filtering, which
  is accomplished by the new 'tcpdump-qeth' (#15626, #22085)
* Mon May 20 2002 postadal@suse.de
- fixed bug in displaying NFS traffic
- updated to version 3.7.1
  * support more protocols
  * better Linux libc5 compat
* Wed Apr  3 2002 postadal@suse.cz
- fixed to compile with autoconf-2.53
* Mon Jun 18 2001 cihlar@suse.cz
- updated to version 3.6.2
- removed obsolete patches
- compile against package libpcap
* Tue Feb  6 2001 ro@suse.de
- tcpclice.c: include time.h
- smbutil.c: include time.h
* Fri Jan 19 2001 bk@suse.de
- Turn off PACKET_RX_RING too. It is not available in lx_sus22 and
  not enabled in our 2.4 kernel configs and causes a warning on
  every start and possible trouble. See bug #5178
* Thu Jan 11 2001 ak@suse.de
- Turn off PACKET_TRECV. It's not enabled in our kernel and causes some
  problems.
* Fri Nov 24 2000 ak@suse.de
- Add mb() for ppc
* Tue Nov 14 2000 ro@suse.de
- groups sorted
* Tue Nov 14 2000 ak@suse.de
- add some protocols to make it build on 6.1 again
* Mon Nov 13 2000 ak@suse.de
- add membar fix for sparc
* Sat Nov 11 2000 ak@suse.de
- fix some buffer overflows.
* Thu May 18 2000 schwab@suse.de
- Fix missing declaration.
- Fix broken includes.
- Get rid of Makefile.Linux and clean up spec file.
- Update config.{sub,guess}.
* Thu May 11 2000 ak@suse.de
- add security fix for endless dns looping. From Guy Harris.
* Thu Mar  2 2000 ak@suse.de
- move man pages to /usr/share/man
* Wed Dec 22 1999 ak@suse.de
- fix promiscuous mode bug
* Fri Dec  3 1999 bk@suse.de
- disabled NO_SMP_DEBUG changes by ank(did not compile on sparc)
* Sat Nov  6 1999 bk@suse.de
- Integrated changes from ak:
  strip tcpdump and a fix a -p crash bug (pcap-maddr-fix)
* Wed Oct 27 1999 bk@suse.de
- Andi Kleen added patches from Alexey Kuznetsov. Features e.g.:
  - device independent libpcap, Kernel support for new link-layers, e.g. ISDN
    (libpcap uses PF_PACKET,SOCK_DGRAM instead of PF_INET,SOCK_PACKET)
  - IPv6 and APM support, SMB updates
  - libpcap support for "In Kernel Packet Filtering" (CONFIG_FILTER)
- made a libpcapn subpackage which holds the new libpcap for developers.
- Added fix to reestablish old output format of tcpdump from Andi Kleen.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Sep 29 1998 ro@suse.de
- print_i4l : include net/ethernet.h instead of netinet/if_ether.h for glibc
* Mon Mar  2 1998 florian@suse.de
- update to version 3.4a6
* Mon Jul  7 1997 florian@suse.de
- update to version 3.4a5
- added isdn-patches
* Mon Jul  7 1997 florian@suse.de
- update to version 3.4a3
* Sun Apr 13 1997 florian@suse.de
- update to new version 3.3.1a2 with automatic detection of packet types
* Thu Jan  2 1997 florian@suse.de
- added the changes distributed with samba
- added isdn patches
